package cn.com.qmth.stmms.admin.exam;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import javax.servlet.http.HttpServletRequest;

import net.sf.json.JSONObject;

import org.apache.commons.lang.StringEscapeUtils;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;

import cn.com.qmth.stmms.biz.exam.model.CheckStudent;
import cn.com.qmth.stmms.biz.exam.model.ExamStudent;
import cn.com.qmth.stmms.biz.exam.query.CheckStudentSearchQuery;
import cn.com.qmth.stmms.biz.exam.service.CheckStudentService;
import cn.com.qmth.stmms.biz.exam.service.ExamStudentService;
import cn.com.qmth.stmms.biz.file.service.FileService;
import cn.com.qmth.stmms.common.annotation.Logging;
import cn.com.qmth.stmms.common.enums.CheckType;
import cn.com.qmth.stmms.common.enums.LogType;

@Controller
@RequestMapping("/admin/exam/check/student")
public class CheckStudentController extends BaseExamController {

    @Autowired
    private ExamStudentService studentService;

    @Autowired
    private CheckStudentService checkStudentService;

    @Autowired
    private FileService fileService;

    @Logging(menu = "人工确认查询", type = LogType.QUERY)
    @RequestMapping
    public String index(Model model, HttpServletRequest request, CheckStudentSearchQuery query) {
        int examId = getSessionExamId(request);
        List<ExamStudent> studentList = new ArrayList<ExamStudent>();
        query.setExamId(examId);
        query.setChecked(false);
        if (query.getType() == null) {
            query.setType(CheckType.MANUAL);
        }
        query = checkStudentService.findByQuery(query);
        for (CheckStudent c : query.getResult()) {
            studentList.add(studentService.findById(c.getStudentId()));
        }
        model.addAttribute("typeList", CheckType.values());
        model.addAttribute("studentList", studentList);
        model.addAttribute("query", query);
        return "modules/exam/checkStudent";
    }

    @RequestMapping("/getSetting")
    @ResponseBody
    public JSONObject getSetting(HttpServletRequest request, @RequestParam CheckType checkType) {
        int examId = getSessionExamId(request);
        JSONObject setting = new JSONObject();
        setting.accumulate("fileServer", fileService.getFileServer());
        List<Integer> ids = new ArrayList<Integer>();
        List<CheckStudent> list = checkStudentService.findByExamIdAndIsCheckedAndType(examId, false, checkType);
        for (CheckStudent student : list) {
            ids.add(student.getStudentId());
        }
        setting.accumulate("studentIds", ids);
        return setting;
    }

    @Logging(menu = "人工确认考生", type = LogType.UPDATE)
    @RequestMapping("/save")
    @ResponseBody
    public Object save(HttpServletRequest request, @RequestParam Integer studentId, @RequestParam String answers) {
        ExamStudent student = studentService.findById(studentId);
        answers = StringEscapeUtils.unescapeHtml(StringUtils.trimToNull(answers));
        CheckStudent cs = checkStudentService.findByStudentId(studentId);
        if (student != null && cs != null) {
            student.setAnswers(answers);
            studentService.save(student);
            cs.setChecked(true);
            cs.setUpdateTime(new Date());
            checkStudentService.save(cs);
            return saveUploadStudent(student);
        } else {
            return false;
        }
    }

}
